==> zio-aws-ec2_2.13-5.17.295.22-sources.jar: zio/aws/ec2/model/DescribeTransitGatewayPolicyTablesRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  TransitGatewayMaxResults,
  TransitGatewayPolicyTableId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeTransitGatewayPolicyTablesRequest(
    transitGatewayPolicyTableIds: Optional[
      Iterable[TransitGatewayPolicyTableId]
    ] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[TransitGatewayMaxResults] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest = {
    import DescribeTransitGatewayPolicyTablesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
      .builder()
      .optionallyWith(
        transitGatewayPolicyTableIds.map(value =>
          value.map { item =>
            TransitGatewayPolicyTableId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.transitGatewayPolicyTableIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => TransitGatewayMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest.ReadOnly =
    zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest
      .wrap(buildAwsValue())
}
object DescribeTransitGatewayPolicyTablesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest =
      zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest(
        transitGatewayPolicyTableIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def transitGatewayPolicyTableIds
        : Optional[List[TransitGatewayPolicyTableId]]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[TransitGatewayMaxResults]
    def nextToken: Optional[String]
    def getTransitGatewayPolicyTableIds
        : ZIO[Any, AwsError, List[TransitGatewayPolicyTableId]] =
      AwsError.unwrapOptionField(
        "transitGatewayPolicyTableIds",
        transitGatewayPolicyTableIds
      )
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, TransitGatewayMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
  ) extends zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest.ReadOnly {
    override val transitGatewayPolicyTableIds
        : Optional[List[TransitGatewayPolicyTableId]] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayPolicyTableIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.TransitGatewayPolicyTableId(item)
        }.toList
      )
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[TransitGatewayMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.TransitGatewayMaxResults(value)
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
  ): zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/DescribeTransitGatewayPolicyTablesRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  TransitGatewayMaxResults,
  TransitGatewayPolicyTableId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeTransitGatewayPolicyTablesRequest(
    transitGatewayPolicyTableIds: Optional[
      Iterable[TransitGatewayPolicyTableId]
    ] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[TransitGatewayMaxResults] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest = {
    import DescribeTransitGatewayPolicyTablesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
      .builder()
      .optionallyWith(
        transitGatewayPolicyTableIds.map(value =>
          value.map { item =>
            TransitGatewayPolicyTableId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.transitGatewayPolicyTableIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => TransitGatewayMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest.ReadOnly =
    zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest
      .wrap(buildAwsValue())
}
object DescribeTransitGatewayPolicyTablesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest =
      zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest(
        transitGatewayPolicyTableIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value),
        dryRun.map(value => value)
      )
    def transitGatewayPolicyTableIds
        : Optional[List[TransitGatewayPolicyTableId]]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[TransitGatewayMaxResults]
    def nextToken: Optional[String]
    def dryRun: Optional[Boolean]
    def getTransitGatewayPolicyTableIds
        : ZIO[Any, AwsError, List[TransitGatewayPolicyTableId]] =
      AwsError.unwrapOptionField(
        "transitGatewayPolicyTableIds",
        transitGatewayPolicyTableIds
      )
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, TransitGatewayMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
  ) extends zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest.ReadOnly {
    override val transitGatewayPolicyTableIds
        : Optional[List[TransitGatewayPolicyTableId]] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayPolicyTableIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.TransitGatewayPolicyTableId(item)
        }.toList
      )
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[TransitGatewayMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.TransitGatewayMaxResults(value)
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayPolicyTablesRequest
  ): zio.aws.ec2.model.DescribeTransitGatewayPolicyTablesRequest.ReadOnly =
    new Wrapper(impl)
}
